Overview
Circup is a software utility that makes it easy to install and update the libraries in the lib folder on your CircuitPython devices. It can install new libraries, and also determine if any libraries need updating and perform that updating.
Circup was originally written by Nicholas Tollervey.
This kind of utility is especially useful with some of our M4 CircuitPython devices that can handle lots of libraries such as the Adafruit Grand Central M4 Express.
The PyPortal is packed with so many features, that it uses a lot of libraries, making this tool especially useful.
Our PyGamer and PyBadge also use quite a few libraries.
Another very popular option is the Adafruit Feather M4 Express.
If you would like something in between, you can go with the Adafruit Metro M4 Express.
If you need a Metro M4 that can also do WiFi, you may like the Adafruit Metro M4 Express Airlift Lite.
Page last edited May 19, 2024
Text editor powered by tinymce.
Prepare for Install
Requirements
You will need to have Python 3.9 or higher, pip, and git installed in order to install circup.
Windows Installation
You can verify that you have Python correctly installed by typing python3 --version at the command prompt and checking that you are running Python 3.9 or higher. If you have Windows 10 and don't currently have it installed, Python is available in the Windows store.
Next, we check that Pip is installed by typing pip3 --version. This should have been installed with Python, but if not, you will need to download and install it. Make sure you are running the latest version of pip by typing pip3 install --upgrade pip.
Finally, make sure git is installed by typing git --version. If this isn't installed, you will need to install a version that you can run from the command line such as git-scm.
After we have verified that we have all the requirements, let's update the Path variable. Getting to this can vary by windows versions, but it's often in the Environment Variable setting dialog, which can be accessed through the System Properties.
To figure out the correct path to add, type the following at the command line:
python3 -m site --user-base
Then copy the path that is returned and add \Python312\Scripts or whatever the latest version is onto the end of your PATH. If your PATH varies due to having a different version of Python, change it accordingly.
Now continue on to the circup installation.
MacOS Installation
You can verify that you have Python correctly installed by typing python3 --version at the command prompt and checking that you are running Python 3.9 or higher. If you don't currently have it installed, Python can easily be installed through a utility called Homebrew.
Next, we check that Pip is installed by typing pip3 --version. This should have been installed with Python, but if not, you will need to download and install it. Make sure you are running the latest version of pip by typing pip3 install --upgrade pip.
Finally, make sure git is installed by typing git --version. If this isn't installed, this can also easily be installed with Homebrew.
Now continue on to the CircUp installation.
Linux Installation
You can easily make sure all three requirements are installed with the following command on a Debian or Ubuntu system:
sudo apt-get install -y python3 git python3-pip
Make sure you are running the latest version of pip by typing pip3 install --upgrade pip.
Now continue on to the CircUp installation.
Python VENV
You will need to setup a venv with modern python3 releases. The activate file will need to be sourced on each subsequent login for circup to work.Â
sudo apt install python3-venv python3 -m venv env source env/bin/activate
Page last edited May 19, 2024
Text editor powered by tinymce.
Install CircUp
After we have verified that we have all the requirements, it's time to install CircUp. Now that it's on PyPI, installation is a snap. Just open up the command line and type the following:
pip install setuptools pip install circup
That's it. After that type circup --version and it should return the version that it's running on. If it returns the version successfully, you should be good to go.
Upgrading to the latest Version
If you already have an older version of CircUp installed through PyPI, you can update to the latest version by typing:
pip install --upgrade circup
Page last edited May 19, 2024
Text editor powered by tinymce.
Usage
Contributing
The utility is still growing and you can check out the GitHub Repo for any outstanding issues. Everyone is welcome to submit Issues and Pull Requests to the Circup Repository to request features or fix bugs.
Let's Go!
Once you have Circup installed, using it involves just typing a few of the available commands:
- install - Install a named module(s) onto the device.
- uninstall - Uninstall a named module(s) from the connected device.
- update - Update modules on the device.
- list - Lists all out of date modules found on the connected device.
- freeze - Output details of all the modules found on the connected.
- example - Copy named example(s) from a bundle onto the device.
- show - Show a list of available modules in the bundle.
- bundle-add, bundle-remove, bundle-show - Manage local bundles.
Argument / Command Order
Except for the --help argument, every other argument that is documented on this page needs to be passed prior to the command being being issued.Â
Correct Examples (Arguments Before Command):
$ circup --host 192.168.1.188 --password Passw0rd install adafruit_display_text $ circup --verbose install adafruit_display_text $ circup --path my_project/ --cpy-version 9.0.0 install adafruit_display_text
Incorrect Examples (Arguments After Command):
$ circup install adafruit_display_text --host 192.168.1.188 --password Passw0rd $ circup install adafruit_display_text --path my_project/ --cpy-version 9.0.0 $ circup install adafruit_display_text --verbose
Informational Commands & Arguments
The following commands do not interact with a microcontroller. They can be used without a device plugged in.
-
circup --help: Print the built-in documentation information into the terminal. If you don't specify any command then it will print an overview of all commands along with the general documentation -
circup [command] --help: Print the built-in documentation about the specified command i.e.circup install --helpwill print documentation and available arguments for the install command. -
circup --version: Print current version of the Circup utility that is installed. -
circup --verbose [command]: Print more verbose output when executing the specified command. Without the --verbose flag specified there is still more verbose information written to a log file, this flag prints that information to the terminal output in addition to the log file.
Web Workflow Arguments
The following arguments are used for interacting with a Circuitpython device via Web Workflow rather than the typical USB Disk Workflow. To connect to the web workflow two things are needed: the hostname or IP address of the device, and the web workflow password that is used to authenticate the requests. Optionally a timeout can be passed to configure how long the tool will wait while attempting to make a connection to the device.
-
--host [hostname_or_ip]: The IP or Hostname of the CircuitPython device to connect to. If omitted Circup will attempt to usecircuitpython.localand find unique hostname from the information returned by the workflow API. If there are multiple devices with web workflow enabled connected to the network then you'll need to specify one with this argument. examples:circup --host 192.168.1.188 [rest of command]circup --host cpy-59689c.local [rest of command]
-
--password [password_value]: The password used to authenticate the web workflow requests. This is configured in settings.toml on the device. example:circup --host 192.168.1.188 --password Passw0rd [rest of command]
Alternatively you can set the environment variable
CIRCUP_WEBWORKFLOW_PASSWORDwith a value equal to the password. Circup will check for this environment variable and attempt to use it's value if it exists. If it doesn't exist, or if the value inside of it is incorrect then the--passwordargument is required to be passed with the correct password in order for Circup to function correctly. After setting the environment variable you can omit the --password argument from circup commands for the remainder of the terminal session example (Linux / Mac):-
export CIRCUP_WEBWORKFLOW_PASSWORD=Passw0rdÂ
-
--timeout [value]: The number of seconds to wait while attempting to connect to the Circuitpython device over the network. The default values is 30 seconds. example setting to 10 seconds:circup --timeout 10 [rest of command]
Disk Path Location Argument
If you have changed your USB Storage device's label to something other than the default CIRCUITPY or if you'd like to use circup to manage libraries in a local project directory instead of directly on a circuitpython device you can use the --path argument.
-
--path [path_value]: A local filepath pointing the local directory that you would like circup to treat as it would the circuitpython device root for the purposes of managing library files. Examples:circup --path CUSTOMDRIVENAME/ [rest of command]circup --path ~/projects/very_cool_project/ [rest of command]circup --path c:\projects\very_cool_project\ [rest of command]
Local Project Directories
If you are using circup to manage libraries within a local project directory on your host PC rather than directly on a Circuitpython device you will also need to pass the --cpy-version argument with a value equal to a valid semantic version string that circup will use when determining which version of MPY file to load.
-
--cpy-version [version]: The version number to use for the purpose of selecting MPY version of the library files. Example:
circup --path cool_project/ --cpy-version 9.0.0 [rest of command]
Auto locating USB Disk based device failed. Please specify --path argument or ensure your device is connected and mounted under the name CIRCUITPY. Could not find a connected CircuitPython device.
Explanation
Circup was unable to automatically locate your device. There are a few possible causes of this.
If your device is connected with a USB cable then ensure that it is appearing to the host PC as the CIRCUITPY drive. If it's not appearing, make sure that you have a working USB cable with data lines. Some USB cables are charging only, and will not work with Circup.
If your device has a custom drive name other than CIRCUITPY then you will need to use the --path argument and pass the path pointing to your drive by it's name.
If your using web workflow then you need to include the --host and --password arguments and pass in the IP address or hostname, and webworkflow password respectively.
Page last edited May 19, 2024
Text editor powered by tinymce.
Install Command
The circup install command is used to install the specified libraries onto the connected device.
$ circup install --help
Usage: circup install [OPTIONS] [MODULES]...
Install a named module(s) onto the device. Multiple modules can be installed
at once by providing more than one module name, each separated by a space.
Modules can be from a Bundle or local filepaths.
Options:
--py Install the .py version of the module(s) instead of
the mpy version.
-r, --requirement FILE specify a text file to install all modules listed in
the text file. Typically requirements.txt.
-a, --auto Install the modules imported in code.py.
-U, --upgrade Upgrade modules that are already installed.
--auto-file TEXT Specify the name of a file on the board to read for
auto install. Also accepts an absolute path or a
local ./ path.
--help Show this message and exit.
Options Details
There are several options specific to the install command that can be used to control it's behavior.
-
--help: Print the built-in documentation of the install command (shown above). -
--py: Load the .py version of the module(s) instead of the .mpy ones. This is helpful if you want to be able to look at the clear text python code for the library for troubleshooting or development purposes. Or if you are testing an awkward core version that has restricted support for mpy versions. -
-r [file],--requirement [file]: Instead of listing module(s) on the command line read them from a text file, typically requirements.txt. The requirements listed in this file can be pypi names likeadafruit-circuitpython-display-textor "import names" likeÂadafruit_display_text. -
-a,--auto: Automatically look for dependencies inside of code.py or the specified auto-file instead of passing module(s) by command line. It will find any libraries imported within the file then install them. -
-u,--upgrade: Force the newly installed library to overwrite the previously installed instance. By default circup will print an error and not overwrite libraries that are already installed. This flag indicates the user wishes to overwrite any existing library versions that are found. The existing libraries are deleted, so be careful if you're modifying your libraries, make sure you backup any important versions! -
--auto-file [file]: Specify the file to use with-a,--auto. If it is not specified thencode.pyis used by default.
Modules Arguments
The final part of the command is a single or space separated list of multiple modules to install. The module names should be the same ones used to import them in code e.g. adafruit_display_text.
Tab Completion
The modules argument supports tab completion while you're entering the modules into terminal. So if you type circup install ad then press the Tab key, it will autocomplete the rest of the word "adafruit_". If you press the Tab key again it will offer to show you all of the possible module names.
$ circup install adafruit_[Tab] Display all 329 possibilities? (y or n)
If you press the y key it will output a list of module names that match the partial entry currently at the end of the command. Depending on the length of the partial module that is currently entered it could be a rather long list. As you get more of the partial module name entered it will narrow down the list of valid module names.Â
$ circup install adafruit_display[Tab] adafruit_display_notification adafruit_displayio_sh1106 adafruit_display_shapes adafruit_displayio_sh1107 adafruit_display_text adafruit_displayio_ssd1305 adafruit_displayio_flipclock adafruit_displayio_ssd1306 adafruit_displayio_layout
If there is only a single possible valid module name it will autocomplete the full name.
$ circup install adafruit_lo[Tab] $ circup install adafruit_logging
$ circup install adafruit_rsa $ circup install adafruit_display_shapes adafruit_display_text $ circup install adafruit_logging --py --upgrade $ circup --path cool_project/ --cpy-version 9.0.0 install adafruit_logging $ circup --host 192.168.1.188 --password Passw0rd install adafruit_display_text $ circup --host 192.168.1.188 --password Passw0rd install --auto
$ circup install adafruit_rsa Found device at /media/myusername/CIRCUITPY, running CircuitPython 8.2.9. A newer version of CircuitPython (9.0.5) is available. Get it here: https://circuitpython.org/board/adafruit_feather_esp32s3_tft Downloading latest bundles for adafruit/Adafruit_CircuitPython_Bundle (20240525). py: Extracting: [####################################] 100% 8.x-mpy: Extracting: [####################################] 100% 9.x-mpy: Extracting: [####################################] 100% OK Downloading latest bundles for adafruit/CircuitPython_Community_Bundle (20240524). py: Extracting: [####################################] 100% 8.x-mpy: Extracting: [####################################] 100% 9.x-mpy: Extracting: [####################################] 100% OK Searching for dependencies for: ['adafruit_rsa'] Ready to install: ['adafruit_hashlib', 'adafruit_logging', 'adafruit_rsa'] 'adafruit_hashlib' is already installed. 'adafruit_logging' is already installed. Installed 'adafruit_rsa'.
circup --host 192.168.1.111 --password Passw0rd install adafruit_display_text Found device at http://:[email protected], running CircuitPython 9.0.5. Searching for dependencies for: ['adafruit_display_text'] Ready to install: ['adafruit_bitmap_font', 'adafruit_display_text'] 'adafruit_bitmap_font' is already installed. Installed 'adafruit_display_text'.
Page last edited May 19, 2024
Text editor powered by tinymce.
Uninstall Command
The circup uninstall command is used to uninstall the specified module(s) from the connected device.
$ circup uninstall --help Usage: circup uninstall [OPTIONS] [MODULE]... Uninstall a named module(s) from the connected device. Multiple modules can be uninstalled at once by providing more than one module name, each separated by a space. Options: --help Show this message and exit.
The uninstall command does not have any other specific options beyond the --help argument which prints the built-in documentation info.
Modules Arguments
The final part of the command is a single or space separated list of multiple modules to uninstall. The module names should be the same ones used to import them in code e.g. adafruit_display_text.
$ circup uninstall adafruit_rsa $ circup uninstall adafruit_display_shapes adafruit_display_text $ circup uninstall adafruit_logging --py --upgrade $ circup --path cool_project/ --cpy-version 9.0.0 uninstall adafruit_logging $ circup --host 192.168.1.188 --password Passw0rd uninstall adafruit_display_text
circup uninstall adafruit_rsa
Found device at /media/myusername/CIRCUITPY, running CircuitPython 9.0.5.
Uninstalling ('adafruit_rsa',) from /media/myusername/CIRCUITPY
Uninstalled 'adafruit_rsa'.
Page last edited May 19, 2024
Text editor powered by tinymce.
Update Command
The circup update command will check all of the libraries on the connected device and prompt the user to install new versions of any that are out of date.
$ circup update --help Usage: circup update [OPTIONS] Checks for out-of-date modules on the connected CIRCUITPYTHON device, and prompts the user to confirm updating such modules. Options: --all Update all modules without Major Version warnings. --help Show this message and exit.
Options Details
As usual the --help argument will print out the built-in documentation information about the command.
The only other option for the update command is the --all argument which will install the new versions of each library without prompting individually for each one.
$ circup update $ circup update --all $ circup --host 192.168.1.188 --password Passw0rd update $ circup --path mock_device/ update
$ circup update Found device at /media/myusername/CIRCUITPY, running CircuitPython 9.0.0-alpha.4. A newer version of CircuitPython (9.0.5) is available. Get it here: https://circuitpython.org/board/adafruit_funhouse Found 1 module[s] needing update. Please indicate which module[s] you wish to update: Update 'adafruit_rsa'? [y/N]: y Updated adafruit_rsa Checking 1 updated module[s] for missing requirements. Ready to install: ['adafruit_hashlib', 'adafruit_logging'] Installed 'adafruit_hashlib'. Installed 'adafruit_logging'.
Page last edited May 19, 2024
Text editor powered by tinymce.
List Command
The circup list command will print a list of all libraries found on the connected device along with whether or not the are up to date.Â
$ circup list --help Auto locating USB Disk based device failed. Please specify --path argument or ensure your device is connected and mounted under the name CIRCUITPY. Usage: circup list [OPTIONS] Lists all out of date modules found on the connected CIRCUITPYTHON device. Options: --help Show this message and exit.
The only argument that the list command supports is --help which prints out the built-in documentation information.
$ circup list $ circup --host 192.168.1.188 --password Passw0rd list $ circup --path mock_device/ list
$ circup list Found device at /media/myusername/CIRCUITPY, running CircuitPython 9.0.5. The following modules are out of date or probably need an update. Major Updates may include breaking changes. Review before updating. MPY Format changes from Circuitpython 8 to 9 require an update. Module Version Latest Update Reason ---------------------------- ------------- ------- -------------- adafruit_connection_manager 1.0.1 3.1.0 Major Version adafruit_ntp 3.0.13 3.1.1 Minor Version adafruit_bme680 3.7.4 3.7.5 Minor Version adafruit_bitmap_font 2.0.2 2.1.1 MPY Format adafruit_minimqtt 7.6.3 7.9.0 Minor Version adafruit_httpserver 4.5.6 4.5.8 Minor Version adafruit_bus_device 5.2.8 5.2.9 Minor Version adafruit_wiznet5k 5.0.9 7.1.1 Major Version adafruit_display_shapes 2.8.2 2.8.3 Minor Version adafruit_itertools 2.1.0 2.1.1 Minor Version
Page last edited May 19, 2024
Text editor powered by tinymce.
Freeze Command
The circup freeze command will output the current libraries installed on the connected device. It outputs each library and the current version loaded.
This is helpful for sharing a list of a requirements for your project to another person or another device.
$ circup freeze --help Usage: circup freeze [OPTIONS] Output details of all the modules found on the connected CIRCUITPYTHON device. Option -r saves output to requirements.txt file Options: -r, --requirement --help Show this message and exit.
Options Details
The --help flag will print out the built-in documentation information.
The -r, or --requirement flag will cause the output to be written into a requirements.txt file instead of being printed to the terminal.
$ circup freeze $ circup freeze -r $ circup freeze --requirement $ circup --host 192.168.1.188 --password Passw0rd freeze $ circup --path mock_device/ freeze $ circup --path cool_project/ --cpy-version 9.0.0 --board-id pygamer freeze
$ circup freeze Found device at /media/myusername/CIRCUITPY, running CircuitPython 9.0.5. adafruit_connection_manager==1.0.1 adafruit_ntp==3.0.13 adafruit_datetime==1.2.7 adafruit_debouncer==2.0.8 adafruit_ticks==1.0.13 adafruit_wave==0.0.3 adafruit_bme680==3.7.4 adafruit_bitmap_font==2.0.2 adafruit_display_text==3.1.0 adafruit_minimqtt==7.6.3 adafruit_io==5.8.2 adafruit_httpserver==4.5.6 adafruit_bus_device==5.2.8 asyncio==1.3.1 adafruit_imageload==1.20.2 adafruit_register==1.9.18
Page last edited May 19, 2024
Text editor powered by tinymce.
Example Command
The circup example command can be used to load the example scripts from any library in a bundle onto the connected device.
$ circup example --help Usage: circup example [OPTIONS] EXAMPLES... Copy named example(s) from a bundle onto the device. Multiple examples can be installed at once by providing more than one example name, each separated by a space. Options: --overwrite Overwrite the file if it exists. --help Show this message and exit.
Options Details
There are only 2 options available for the example command. --help which prints the built-in documentation information.
The --overwrite option will direct the command to overwrite the existing copy of the example script on the device if one exists. Without this flag the command will output an error if it finds an existing example already on the device. If you modify example scripts be careful to backup any modified copies of examples on your device if you do use the --overwrite command.
Examples Arguments
The final part of the command is a single or space separated list of examples to copy to the connected device. The examples must be in the form of lib_shortname/example_name e.g. neopixel/neopixel_simpletest or logging/logging_simpletest.
Tab Completion
The examples argument supports tab completion to autocomplete valid library and example names. So if you enter a partial library short name it will either autocomplete fully if there is only a single valid match, or autocomplete as much as it can if there are multiple possible matches based on the partial entry.
$ circup example req[Tab] # auto completes to: $ circup example requests/ $ circup example neopixel/neopixel_s[Tab] # auto completes to: $ circup example neopixel/neopixel_simpletest
If you press the [Tab] key twice it will print out the list of possible matches based upon the current partial value entered.
$ circup example neopixel/[Tab] # auto completes to: $ circup example neopixel/neopixel_ # press [Tab] twice more neopixel/neopixel_pixel neopixel/neopixel_rpi_simpletest neopixel/neopixel_rainbowio_simpletest neopixel/neopixel_simpletest
$ circup example neopixel/neopixel_simpletest $ circup --host 192.168.1.188 --password Passw0rd example display-shapes/display_shapes_simpletest $ circup example display-shapes/display_shapes_simpletest display-shapes/display_shapes_circle_animation
$ circup example neopixel/neopixel_simpletest Found device at /media/myusername/CIRCUITPY, running CircuitPython 9.0.5. Copying: neopixel_simpletest.py
Page last edited May 19, 2024
Text editor powered by tinymce.
Show Command
The circup show command will print a list of all libraries that are available in any bundles that circup is aware of.Â
The list is rather long, 487 libraries at the time of this writing, so be prepared to do some scrolling if you're trying to find something specific within it. The optional MATCH argument can be used to narrow the list to libraries of interest by searching for a specific string.
$ circup show --help Usage: circup show [OPTIONS] [MATCH] Show a list of available modules in the bundle. These are modules which *could* be installed on the device. If MATCH is specified only matching modules will be listed. Options: --help Show this message and exit.
Match Argument
The match argument is optional. If passed the list will be narrowed down to only libraries that include the string specified. This can be used to help find libraries you are interested in by searching for keywords like circup show ble to find libraries related to BLE for example.
$ circup show $ circup show ble $ circup show spark $ circup show display
$ circup show AT24MAC_EEPROM P1AM absolute_mouse adafruit_24lc32 adafruit_74hc595 adafruit_acep7in # ...
$ circup show ssd adafruit_displayio_ssd1305 adafruit_displayio_ssd1306 adafruit_ssd1305 adafruit_ssd1306 adafruit_ssd1322 adafruit_ssd1325 adafruit_ssd1327 adafruit_ssd1331 adafruit_ssd1351 adafruit_ssd1608 adafruit_ssd1675 adafruit_ssd1680 adafruit_ssd1681 13 shown of 487 packages.
Page last edited May 19, 2024
Text editor powered by tinymce.
Bundle Commands
The remaining commands all pertain managing the bundles on your local system that circup will look for libraries inside of. By default circup uses these 3 bundles:
- Adafruit Library Bundle
- Community Library Bundle
- CircuitPython Org Bundle
These commands allow you to add and remove other 3rd party bundles if you'd like. Once added then circup will be able to install libraries from those 3rd party bundles.
If you don't want to use any 3rd party bundles then you won't need to use these commands.Â
Bundle Show Command
The circup bundle-show command will print a list of the currently tracked bundles, and information about the current versions.
$ circup bundle-show --help Usage: circup bundle-show [OPTIONS] Show the list of bundles, default and local, with URL, current version and latest version retrieved from the web. Options: --modules List all the modules per bundle. --help Show this message and exit.
Options Details
The --help argument will print the built-in documentation information.
The --modules argument will print the list of libraries within each bundle in additional to the bundle information. This is similar to the output from the circup show command, but the libraries are grouped by which bundle their in and split up.Â
$ circup bundle-show $ circup bundle-show --modules
$ circup bundle-show
adafruit/Adafruit_CircuitPython_Bundle
https://github.com/adafruit/Adafruit_CircuitPython_Bundle
version = 20240525
adafruit/CircuitPython_Community_Bundle
https://github.com/adafruit/CircuitPython_Community_Bundle
version = 20240524
circuitpython/CircuitPython_Org_Bundle
https://github.com/circuitpython/CircuitPython_Org_Bundle
version = 20231031.2
Bundle Add Command
The circup bundle-add command will add a new bundle to be tracked by circup.Â
One such possible bundle is the CircuitPython Fonts Bundle. It contains several sizes of different open source fonts formatted to work with Circuitpython displayio.
You only need to run this command once to add a bundle. After it comples circup will track the added bundle and download new versions to your computer when they're available. You will also be able to install libraries from the added bundle.
$ circup bundle-add --help Usage: circup bundle-add [OPTIONS] [BUNDLE]... Add bundles to the local bundles list, by "user/repo" github string. A series of tests to validate that the bundle exists and at least looks like a bundle are done before validating it. There might still be errors when the bundle is downloaded for the first time. Options: --help Show this message and exit.
Options Details
The only optional argument is the --help flag which prints the built-in documentation information.Â
The final part of the command is the Bundle argument, it is required and must be in the format of a user/repository string pointing to a valid library bundle hosted on Github.
$ circup bundle-add adafruit/circuitpython-fonts
$ circup bundle-add adafruit/circuitpython-fonts
Added adafruit/circuitpython-fonts
https://github.com/adafruit/circuitpython-fonts
Bundle Remove Command
The circup bundle-remove command is the opposite of the bundle-add command. circup bundle-remove will remove the specified bundle from your computer and circup will stop tracking it. After removal you will not be able to install the libraries from that bundle any longer.
$ circup bundle-remove --help Usage: circup bundle-remove [OPTIONS] [BUNDLE]... Remove one or more bundles from the local bundles list. Options: --reset Remove all local bundles. --help Show this message and exit.
Options Details
The --help argument will print out the built-in documentation information.Â
The --reset argument will remove all non-default bundles that have been previously added.Â
Bundle Argument
If you do not use the --reset argument, then the final part of this command is the Bundle argument. Just as with bundle-add the value must be in the format of a user/repository string. If you're unsure about the correct names to use then run the circup bundle-show command to see the bundles that are installed and then choose the one that you want to install and copy the name printed out.
$ circup bundle-remove adafruit/circuitpython-fonts $ circup bundle-remove --reset
$ circup bundle-remove adafruit/circuitpython-fonts
Bundle adafruit/circuitpython-fonts
Do you want to remove that bundle ? [y/N]: y
Removing the bundle from the local list
adafruit/circuitpython-fonts
Page last edited May 19, 2024
Text editor powered by tinymce.